@@ -3,9 +3,9 @@
 These tests verify that the MCP tool implementations conform to the contract
 specifications defined in contracts/navigation_tools.json and read_project_context.json.
 """
+
 import pytest
-from pathlib import Path
-from agent_mcp.tools.navigation import list_directory, show_tree, read_project_context
+from context_mcp.tools.navigation import list_directory, show_tree, read_project_context
 
 
 class TestListDirectoryContract:
@@ -74,13 +74,79 @@ class TestListDirectoryContract:
         """Test PATH_SECURITY_ERROR is raised for paths outside root."""
         with pytest.raises(Exception) as exc_info:
             list_directory(path="../../etc")
-        assert "PATH_SECURITY_ERROR" in str(exc_info.value) or "outside root" in str(exc_info.value).lower()
+        assert (
+            "PATH_SECURITY_ERROR" in str(exc_info.value)
+            or "outside root" in str(exc_info.value).lower()
+        )
 
     def test_error_path_not_found(self):
         """Test PATH_NOT_FOUND error for non-existent directory."""
         with pytest.raises(Exception) as exc_info:
             list_directory(path="nonexistent_directory_xyz")
-        assert "PATH_NOT_FOUND" in str(exc_info.value) or "not exist" in str(exc_info.value).lower()
+        assert (
+            "PATH_NOT_FOUND" in str(exc_info.value)
+            or "not exist" in str(exc_info.value).lower()
+        )
+
+    def test_limit_zero(self):
+        """Test that limit=0 returns empty list but correct total count."""
+        result = list_directory(path=".", limit=0)
+        assert result["entries"] == []
+        assert result["total"] > 0  # Actual directory has files
+        assert result["truncated"] is True
+
+    def test_limit_one(self):
+        """Test that limit=1 returns single entry."""
+        result = list_directory(path=".", limit=1)
+        assert len(result["entries"]) == 1
+        assert result["total"] > 0
+        # truncated is True if total > 1
+        if result["total"] > 1:
+            assert result["truncated"] is True
+
+    def test_sort_by_size_order_desc(self):
+        """Test sorting by size in descending order."""
+        result = list_directory(path=".", sort_by="size", order="desc")
+        if len(result["entries"]) > 1:
+            # First entry should have size >= last entry
+            assert result["entries"][0]["size"] >= result["entries"][-1]["size"]
+
+    def test_sort_by_size_order_asc(self):
+        """Test sorting by size in ascending order."""
+        result = list_directory(path=".", sort_by="size", order="asc")
+        if len(result["entries"]) > 1:
+            # First entry should have size <= last entry
+            assert result["entries"][0]["size"] <= result["entries"][-1]["size"]
+
+    def test_sort_by_time_order_desc(self):
+        """Test sorting by time in descending order."""
+        result = list_directory(path=".", sort_by="time", order="desc")
+        if len(result["entries"]) > 1:
+            # First entry should have mtime >= last entry
+            assert result["entries"][0]["mtime"] >= result["entries"][-1]["mtime"]
+
+    def test_sort_by_time_order_asc(self):
+        """Test sorting by time in ascending order."""
+        result = list_directory(path=".", sort_by="time", order="asc")
+        if len(result["entries"]) > 1:
+            # First entry should have mtime <= last entry
+            assert result["entries"][0]["mtime"] <= result["entries"][-1]["mtime"]
+
+    def test_sort_by_name_order_desc(self):
+        """Test sorting by name in descending order."""
+        result = list_directory(path=".", sort_by="name", order="desc")
+        if len(result["entries"]) > 1:
+            # Verify descending alphabetical order
+            names = [e["name"] for e in result["entries"]]
+            assert names == sorted(names, reverse=True)
+
+    def test_sort_by_name_order_asc(self):
+        """Test sorting by name in ascending order."""
+        result = list_directory(path=".", sort_by="name", order="asc")
+        if len(result["entries"]) > 1:
+            # Verify ascending alphabetical order
+            names = [e["name"] for e in result["entries"]]
+            assert names == sorted(names)
 
 
 class TestShowTreeContract:
@@ -149,13 +215,31 @@ class TestShowTreeContract:
         """Test PATH_SECURITY_ERROR is raised for paths outside root."""
         with pytest.raises(Exception) as exc_info:
             show_tree(path="../../etc")
-        assert "PATH_SECURITY_ERROR" in str(exc_info.value) or "outside root" in str(exc_info.value).lower()
+        assert (
+            "PATH_SECURITY_ERROR" in str(exc_info.value)
+            or "outside root" in str(exc_info.value).lower()
+        )
 
     def test_error_path_not_found(self):
         """Test PATH_NOT_FOUND error for non-existent directory."""
         with pytest.raises(Exception) as exc_info:
             show_tree(path="nonexistent_directory_xyz")
-        assert "PATH_NOT_FOUND" in str(exc_info.value) or "not exist" in str(exc_info.value).lower()
+        assert (
+            "PATH_NOT_FOUND" in str(exc_info.value)
+            or "not exist" in str(exc_info.value).lower()
+        )
+
+    def test_max_depth_zero_rejected(self):
+        """Test that max_depth=0 raises ValueError."""
+        with pytest.raises(ValueError) as exc_info:
+            show_tree(path=".", max_depth=0)
+        assert "must be between 1 and 10" in str(exc_info.value)
+
+    def test_max_depth_eleven_rejected(self):
+        """Test that max_depth=11 raises ValueError."""
+        with pytest.raises(ValueError) as exc_info:
+            show_tree(path=".", max_depth=11)
+        assert "must be between 1 and 10" in str(exc_info.value)
 
 
 @pytest.mark.contract
@@ -172,9 +256,10 @@ class TestReadProjectContextContract:
         (tmp_path / "CLAUDE.md").write_text(claude_content, encoding="utf-8")
 
         # Mock config module
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -212,9 +297,10 @@ class TestReadProjectContextContract:
         agents_content = "# Universal Agent Instructions\nProject conventions..."
         (tmp_path / "AGENTS.md").write_text(agents_content, encoding="utf-8")
 
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -243,9 +329,10 @@ class TestReadProjectContextContract:
         claude_content = "# Claude-specific rules\nCode style preferences..."
         (tmp_path / "CLAUDE.md").write_text(claude_content, encoding="utf-8")
 
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -268,9 +355,10 @@ class TestReadProjectContextContract:
     def test_no_files_exist(self, tmp_path, monkeypatch):
         """Test case: Neither AGENTS.md nor CLAUDE.md exist in PROJECT_ROOT."""
         # Setup: Empty directory (no context files)
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -292,9 +380,10 @@ class TestReadProjectContextContract:
         # Setup: Create empty AGENTS.md
         (tmp_path / "AGENTS.md").write_text("", encoding="utf-8")
 
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -314,6 +403,7 @@ class TestReadProjectContextContract:
     def test_permission_denied(self, tmp_path, monkeypatch):
         """Test case: AGENTS.md exists but cannot be read due to permission error."""
         import sys
+
         if sys.platform == "win32":
             pytest.skip("Permission testing requires POSIX platform")
 
@@ -322,9 +412,10 @@ class TestReadProjectContextContract:
         agents_file.write_text("# Protected content", encoding="utf-8")
         agents_file.chmod(0o000)  # Remove all permissions
 
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         try:
             # Execute
@@ -350,9 +441,10 @@ class TestReadProjectContextContract:
         claude_file = tmp_path / "CLAUDE.md"
         claude_file.write_bytes(b"# Valid start\n\xff\xfe\nInvalid bytes")
 
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -367,7 +459,10 @@ class TestReadProjectContextContract:
         assert claude_file_result["readable"] is False
         assert claude_file_result["content"] is None
         assert claude_file_result["error"] is not None
-        assert "encoding" in claude_file_result["error"].lower() or "decode" in claude_file_result["error"].lower()
+        assert (
+            "encoding" in claude_file_result["error"].lower()
+            or "decode" in claude_file_result["error"].lower()
+        )
 
     def test_large_file(self, tmp_path, monkeypatch, caplog):
         """Test case: AGENTS.md is larger than 1MB (warning logged but file still returned)."""
@@ -377,9 +472,10 @@ class TestReadProjectContextContract:
         large_content = "A" * (1024 * 1024 + 100)  # 1MB + 100 bytes
         (tmp_path / "AGENTS.md").write_text(large_content, encoding="utf-8")
 
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute with log capturing
         with caplog.at_level(logging.WARNING):
@@ -399,9 +495,10 @@ class TestReadProjectContextContract:
 
     def test_output_schema_required_fields(self, tmp_path, monkeypatch):
         """Test that output contains all required fields according to contract."""
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.config import ProjectConfig
+
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         result = read_project_context()
 
@@ -436,7 +533,9 @@ class TestReadProjectContextContract:
             # Optional fields
             if file_info["exists"]:
                 assert "size_bytes" in file_info
-                assert file_info["size_bytes"] is None or isinstance(file_info["size_bytes"], int)
+                assert file_info["size_bytes"] is None or isinstance(
+                    file_info["size_bytes"], int
+                )
 
             assert "content" in file_info
             assert file_info["content"] is None or isinstance(file_info["content"], str)
