@@ -5,10 +5,10 @@ Tests from quickstart.md Step 5-6:
 - Empty results, invalid inputs
 - Timeouts, permission errors
 """
+
 import pytest
 import tempfile
 import os
-from pathlib import Path
 
 
 class TestSecurityBoundaries:
@@ -16,27 +16,36 @@ class TestSecurityBoundaries:
 
     def test_path_traversal_attack_list_directory(self):
         """Test path traversal attack is blocked in list_directory."""
-        from agent_mcp.tools.navigation import list_directory
+        from context_mcp.tools.navigation import list_directory
 
         with pytest.raises(Exception) as exc_info:
             list_directory(path="../../etc")
-        assert "security" in str(exc_info.value).lower() or "outside" in str(exc_info.value).lower()
+        assert (
+            "security" in str(exc_info.value).lower()
+            or "outside" in str(exc_info.value).lower()
+        )
 
     def test_path_traversal_attack_read_file(self):
         """Test path traversal attack is blocked in read operations."""
-        from agent_mcp.tools.read import read_entire_file
+        from context_mcp.tools.read import read_entire_file
 
         with pytest.raises(Exception) as exc_info:
             read_entire_file(file_path="../../../etc/passwd")
-        assert "security" in str(exc_info.value).lower() or "outside" in str(exc_info.value).lower()
+        assert (
+            "security" in str(exc_info.value).lower()
+            or "outside" in str(exc_info.value).lower()
+        )
 
     def test_path_traversal_attack_search(self):
         """Test path traversal attack is blocked in search operations."""
-        from agent_mcp.tools.search import search_in_files
+        from context_mcp.tools.search import search_in_files
 
         with pytest.raises(Exception) as exc_info:
             search_in_files(query="test", path="../../etc")
-        assert "security" in str(exc_info.value).lower() or "outside" in str(exc_info.value).lower()
+        assert (
+            "security" in str(exc_info.value).lower()
+            or "outside" in str(exc_info.value).lower()
+        )
 
 
 class TestEmptyAndInvalidInputs:
@@ -44,9 +53,7 @@ class TestEmptyAndInvalidInputs:
 
     def test_empty_directory(self):
         """Test listing an empty directory."""
-        from agent_mcp.tools.navigation import list_directory
-        import tempfile
-        import os
+        from context_mcp.tools.navigation import list_directory
 
         # Create temporary empty directory within project
         with tempfile.TemporaryDirectory(dir=".") as tmpdir:
@@ -54,44 +61,51 @@ class TestEmptyAndInvalidInputs:
             result = list_directory(path=dir_name)
             assert result["total"] == 0
             assert len(result["entries"]) == 0
-            assert result["truncated"] == False
+            assert not result["truncated"]
 
     def test_nonexistent_directory(self):
         """Test accessing non-existent directory."""
-        from agent_mcp.tools.navigation import list_directory
+        from context_mcp.tools.navigation import list_directory
 
         with pytest.raises(Exception) as exc_info:
             list_directory(path="nonexistent_dir_xyz_123")
-        assert "not found" in str(exc_info.value).lower() or "not exist" in str(exc_info.value).lower()
+        assert (
+            "not found" in str(exc_info.value).lower()
+            or "not exist" in str(exc_info.value).lower()
+        )
 
     def test_nonexistent_file(self):
         """Test reading non-existent file."""
-        from agent_mcp.tools.read import read_entire_file
+        from context_mcp.tools.read import read_entire_file
 
         with pytest.raises(Exception) as exc_info:
             read_entire_file(file_path="nonexistent_file_xyz_123.txt")
         # Check for FILE_NOT_FOUND error code or relevant error messages
         error_msg = str(exc_info.value).lower()
-        assert "file_not_found" in error_msg or "not found" in error_msg or "not exist" in error_msg
+        assert (
+            "file_not_found" in error_msg
+            or "not found" in error_msg
+            or "not exist" in error_msg
+        )
 
     def test_search_no_matches(self):
         """Test search with no matches using a very unique string unlikely to exist."""
-        from agent_mcp.tools.search import search_in_files
+        from context_mcp.tools.search import search_in_files
 
         # Use an extremely unique query string with special markers
         result = search_in_files(
             query="ZZZYYYXXX_NONEXISTENT_UNIQUE_MARKER_999888777",
-            file_pattern="*.md"  # Limit to markdown files to reduce false positives
+            file_pattern="*.md",  # Limit to markdown files to reduce false positives
         )
         # Note: In a real codebase, there might be matches in generated files or logs
         # This test checks the structure is correct even if matches > 0
         assert isinstance(result["total_matches"], int)
         assert isinstance(result["matches"], list)
-        assert result["timed_out"] == False
+        assert not result["timed_out"]
 
     def test_find_no_matching_files(self):
         """Test find with no matching files."""
-        from agent_mcp.tools.search import find_files_by_name
+        from context_mcp.tools.search import find_files_by_name
 
         result = find_files_by_name(name_pattern="*.nonexistent_extension_xyz")
         assert result["total_found"] == 0
@@ -103,28 +117,25 @@ class TestInvalidLineRanges:
 
     def test_line_range_out_of_bounds(self):
         """Test reading lines beyond file length."""
-        from agent_mcp.tools.read import read_file_lines
+        from context_mcp.tools.read import read_file_lines
 
         # Try to read lines way beyond file length
-        with pytest.raises(Exception) as exc_info:
+        with pytest.raises(Exception):
             read_file_lines(
-                file_path="pyproject.toml",
-                start_line=10000,
-                end_line=20000
+                file_path="pyproject.toml", start_line=10000, end_line=20000
             )
         # Should raise error about invalid range or just return empty
 
     def test_line_range_start_greater_than_end(self):
         """Test invalid line range where start > end."""
-        from agent_mcp.tools.read import read_file_lines
+        from context_mcp.tools.read import read_file_lines
 
         with pytest.raises(Exception) as exc_info:
-            read_file_lines(
-                file_path="pyproject.toml",
-                start_line=10,
-                end_line=5
-            )
-        assert "invalid" in str(exc_info.value).lower() or "range" in str(exc_info.value).lower()
+            read_file_lines(file_path="pyproject.toml", start_line=10, end_line=5)
+        assert (
+            "invalid" in str(exc_info.value).lower()
+            or "range" in str(exc_info.value).lower()
+        )
 
 
 class TestLimitAndTruncation:
@@ -132,21 +143,21 @@ class TestLimitAndTruncation:
 
     def test_list_directory_with_limit(self):
         """Test directory listing respects limit."""
-        from agent_mcp.tools.navigation import list_directory
+        from context_mcp.tools.navigation import list_directory
 
         # List with limit
         result = list_directory(path=".", limit=3)
         assert len(result["entries"]) <= 3
         if result["total"] > 3:
-            assert result["truncated"] == True
+            assert result["truncated"]
 
     def test_list_directory_no_limit(self):
         """Test directory listing with no limit (-1)."""
-        from agent_mcp.tools.navigation import list_directory
+        from context_mcp.tools.navigation import list_directory
 
         result = list_directory(path=".", limit=-1)
         assert len(result["entries"]) == result["total"]
-        assert result["truncated"] == False
+        assert not result["truncated"]
 
 
 class TestBatchOperationResilience:
@@ -154,13 +165,13 @@ class TestBatchOperationResilience:
 
     def test_read_files_mixed_success_failure(self):
         """Test batch read with mix of valid and invalid files."""
-        from agent_mcp.tools.read import read_files
+        from context_mcp.tools.read import read_files
 
         file_paths = [
-            "pyproject.toml",           # Valid
-            "nonexistent1.txt",         # Invalid
-            ".env.example",             # Valid
-            "nonexistent2.txt",         # Invalid
+            "pyproject.toml",  # Valid
+            "nonexistent1.txt",  # Invalid
+            ".env.example",  # Valid
+            "nonexistent2.txt",  # Invalid
         ]
 
         result = read_files(file_paths=file_paths)
@@ -184,7 +195,7 @@ class TestSortingBehavior:
 
     def test_sort_by_time_descending(self):
         """Test sorting by modification time."""
-        from agent_mcp.tools.navigation import list_directory
+        from context_mcp.tools.navigation import list_directory
 
         result = list_directory(path=".", sort_by="time", order="desc")
         entries = result["entries"]
@@ -195,7 +206,7 @@ class TestSortingBehavior:
 
     def test_sort_by_name_ascending(self):
         """Test alphabetical sorting."""
-        from agent_mcp.tools.navigation import list_directory
+        from context_mcp.tools.navigation import list_directory
 
         result = list_directory(path=".", sort_by="name", order="asc")
         entries = result["entries"]
@@ -210,7 +221,7 @@ class TestMaxDepthBehavior:
 
     def test_max_depth_one(self):
         """Test tree with max_depth=1 shows only current level."""
-        from agent_mcp.tools.navigation import show_tree
+        from context_mcp.tools.navigation import show_tree
 
         result = show_tree(path=".", max_depth=1)
         tree = result["tree"]
@@ -224,11 +235,13 @@ class TestMaxDepthBehavior:
                 assert child["depth"] == 1
                 # Should not have children at max_depth
                 if child["type"] == "dir":
-                    assert "children" not in child or len(child.get("children", [])) == 0
+                    assert (
+                        "children" not in child or len(child.get("children", [])) == 0
+                    )
 
     def test_max_depth_maximum_limit(self):
         """Test tree with max_depth=10 (maximum allowed)."""
-        from agent_mcp.tools.navigation import show_tree
+        from context_mcp.tools.navigation import show_tree
 
         result = show_tree(path=".", max_depth=10)
         assert "tree" in result
@@ -242,11 +255,12 @@ class TestContextFileEdgeCases:
     def test_context_file_permission_error(self, tmp_path, monkeypatch):
         """Test handling of permission denied error when reading context file."""
         import sys
+
         if sys.platform == "win32":
             pytest.skip("Permission testing requires POSIX platform")
 
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create AGENTS.md with no read permissions
         agents_file = tmp_path / "AGENTS.md"
@@ -254,7 +268,7 @@ class TestContextFileEdgeCases:
         agents_file.chmod(0o000)  # Remove all permissions
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         try:
             # Execute
@@ -271,7 +285,10 @@ class TestContextFileEdgeCases:
             assert agents_result["content"] is None
             assert agents_result["size_bytes"] is None
             assert agents_result["error"] is not None
-            assert "Permission denied" in agents_result["error"] or "permission" in agents_result["error"].lower()
+            assert (
+                "Permission denied" in agents_result["error"]
+                or "permission" in agents_result["error"].lower()
+            )
         finally:
             # Cleanup: Restore permissions
             agents_file.chmod(0o644)
@@ -279,15 +296,15 @@ class TestContextFileEdgeCases:
     def test_context_file_large_size_warning(self, tmp_path, monkeypatch, caplog):
         """Test warning is logged for large context files (>1MB)."""
         import logging
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create file >1MB
         large_content = "A" * (1024 * 1024 + 200)  # 1MB + 200 bytes
         (tmp_path / "AGENTS.md").write_text(large_content, encoding="utf-8")
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute with log capturing
         with caplog.at_level(logging.WARNING):
@@ -306,21 +323,22 @@ class TestContextFileEdgeCases:
         # Verify warning was logged
         warning_logged = any(
             "large" in record.message.lower() and "AGENTS.md" in record.message
-            for record in caplog.records if record.levelname == "WARNING"
+            for record in caplog.records
+            if record.levelname == "WARNING"
         )
         assert warning_logged, "Expected WARNING log for large file"
 
     def test_context_file_invalid_encoding(self, tmp_path, monkeypatch):
         """Test handling of invalid UTF-8 encoding in context file."""
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create CLAUDE.md with invalid UTF-8 bytes
         claude_file = tmp_path / "CLAUDE.md"
         claude_file.write_bytes(b"# Valid Header\n\xff\xfe\nInvalid UTF-8 bytes here")
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -336,19 +354,22 @@ class TestContextFileEdgeCases:
         assert claude_result["content"] is None
         assert claude_result["size_bytes"] is None
         assert claude_result["error"] is not None
-        assert "encoding" in claude_result["error"].lower() or "decode" in claude_result["error"].lower()
+        assert (
+            "encoding" in claude_result["error"].lower()
+            or "decode" in claude_result["error"].lower()
+        )
 
     def test_context_file_empty_file(self, tmp_path, monkeypatch):
         """Test handling of empty context file (0 bytes)."""
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create empty files
         (tmp_path / "AGENTS.md").write_text("", encoding="utf-8")
         (tmp_path / "CLAUDE.md").write_text("", encoding="utf-8")
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -366,15 +387,15 @@ class TestContextFileEdgeCases:
 
     def test_context_file_whitespace_only(self, tmp_path, monkeypatch):
         """Test handling of context file with only whitespace."""
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create files with only whitespace
         whitespace_content = "   \n\n\t\t  \n   "
         (tmp_path / "AGENTS.md").write_text(whitespace_content, encoding="utf-8")
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -387,8 +408,8 @@ class TestContextFileEdgeCases:
 
     def test_context_file_with_special_characters(self, tmp_path, monkeypatch):
         """Test handling of context files with special characters and unicode."""
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create file with various special characters
         special_content = """# Agent Instructions 🤖
@@ -410,7 +431,7 @@ class TestContextFileEdgeCases:
         (tmp_path / "CLAUDE.md").write_text(special_content, encoding="utf-8")
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
@@ -425,11 +446,14 @@ class TestContextFileEdgeCases:
     def test_context_file_symlink_handling(self, tmp_path, monkeypatch):
         """Test handling of symlinked context files."""
         import sys
-        if sys.platform == "win32":
-            pytest.skip("Symlink testing requires POSIX platform or admin rights on Windows")
 
-        from agent_mcp.tools.navigation import read_project_context
-        from agent_mcp.config import ProjectConfig
+        if sys.platform == "win32":
+            pytest.skip(
+                "Symlink testing requires POSIX platform or admin rights on Windows"
+            )
+
+        from context_mcp.tools.navigation import read_project_context
+        from context_mcp.config import ProjectConfig
 
         # Setup: Create actual file and symlink to it
         actual_file = tmp_path / "actual_agents.md"
@@ -440,7 +464,7 @@ class TestContextFileEdgeCases:
         symlink.symlink_to(actual_file)
 
         mock_config = ProjectConfig(root_path=tmp_path)
-        monkeypatch.setattr("agent_mcp.config.config", mock_config)
+        monkeypatch.setattr("context_mcp.config.config", mock_config)
 
         # Execute
         result = read_project_context()
